Repository: mesos
Updated Branches:
  refs/heads/master 32920c371 -> f6aa4b04d


Fixed verify-reviews.py to not apply submitted reviews.

Review: https://reviews.apache.org/r/26827


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/f6aa4b04
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/f6aa4b04
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/f6aa4b04

Branch: refs/heads/master
Commit: f6aa4b04d2e669e1e6cbcaf8fb708ab1cd6410eb
Parents: 32920c3
Author: Cody Maloney <[email protected]>
Authored: Thu Oct 16 15:54:28 2014 -0700
Committer: Benjamin Mahler <[email protected]>
Committed: Thu Oct 16 15:56:39 2014 -0700

----------------------------------------------------------------------
 support/verify-reviews.py | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/f6aa4b04/support/verify-reviews.py
----------------------------------------------------------------------
diff --git a/support/verify-reviews.py b/support/verify-reviews.py
index 9408747..ec8a108 100755
--- a/support/verify-reviews.py
+++ b/support/verify-reviews.py
@@ -79,9 +79,10 @@ def apply_reviews(review_request, applied):
         print "Dependent review: %s " % review_url
         apply_reviews(api(review_url)["review_request"], applied)
 
     # Now apply this review.
     applied.append(review_request["id"])
-    apply_review(review_request["id"])
+    if review_request["status"] != "submitted":
+      apply_review(review_request["id"])
 
 
 def post_review(review_request, message):
@@ -79,9 +79,10 @@ def apply_reviews(review_request, applied):
         apply_reviews(api(review_url)["review_request"], applied)
 
-    # Now apply this review.
+    # Now apply this review if not yet submitted.
     applied.append(review_request["id"])

Reply via email to